Create a ggplot object from ggpop data
ggpop.RdCreates a ggplot2 object from typed ggpop data so users can add ggpop geoms with the standard `+` syntax.
Usage
ggpop(data, mapping = ggplot2::aes(), ..., module = NULL)
ggpop.RdCreates a ggplot2 object from typed ggpop data so users can add ggpop geoms with the standard `+` syntax.
ggpop(data, mapping = ggplot2::aes(), ..., module = NULL)