Skip to content

High-level publication-oriented PCA plot builder. When `pop_group` was supplied to `import_pca()`, population groups are mapped to the unified ggpop discrete colour scale by default.

Usage

plot_pca(data, title = NULL, subtitle = NULL, caption = NULL,
  pc_x = 1, pc_y = 2, point_size = 2.16, point_alpha = 0.9,
  base_size = 11, base_family = "", legend_position = "right",
  palette = NULL, ...)

Arguments

data

A `ggpop_pca` object.

title, subtitle, caption

Plot text.

pc_x, pc_y

Principal components to plot.

point_size, point_alpha

Point appearance.

base_size, base_family, legend_position

Publication theme settings.

palette

Discrete ggpop palette name or hex vector for population colours.

...

Additional layer arguments.